Documentation
¶
Index ¶
- type Project
- type Service
- func (s *Service) Create(name, description string) (*Project, error)
- func (s *Service) Delete(name string) error
- func (s *Service) Invite(email, role string) error
- func (s *Service) List() ([]Project, error)
- func (s *Service) Update(oldName, newName, desc string) error
- func (s *Service) Use(name string) (*Project, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Project ¶
type Project struct {
ID string `json:"id"`
Name string `json:"name"`
Description string `json:"description"`
WorkspaceID string `json:"workspace_id"`
}
Project represents a project in a workspace
type Service ¶
Service handles project orchestration
func NewService ¶
NewService creates a new project service
func (*Service) Invite ¶
Invite invites a user to the current project by email, potentially migrating a personal workspace to a shared one.
Click to show internal directories.
Click to hide internal directories.